==> kubernetes-model-1.0.15-sources.jar: annotations/io/fabric8/openshift/api/model/ExecNewPodHookBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;

public class ExecNewPodHookBuilder extends ExecNewPodHookFluent<ExecNewPodHookBuilder> implements VisitableBuilder<ExecNewPodHook,ExecNewPodHookBuilder>{

     ExecNewPodHookFluent<?> fluent;
public ExecNewPodHookBuilder(){
    this(new ExecNewPodHook());
}
public ExecNewPodHookBuilder( ExecNewPodHookFluent<?> fluent ){
    this(fluent, new ExecNewPodHook());
}
public ExecNewPodHookBuilder( ExecNewPodHookFluent<?> fluent , ExecNewPodHook instance ){
    this.fluent = fluent; fluent.withCommand(instance.getCommand()); fluent.withContainerName(instance.getContainerName()); fluent.withEnv(instance.getEnv()); 
}
public ExecNewPodHookBuilder( ExecNewPodHook instance ){
    this.fluent = this; this.withCommand(instance.getCommand()); this.withContainerName(instance.getContainerName()); this.withEnv(instance.getEnv()); 
}

public EditableExecNewPodHook build(){
    EditableExecNewPodHook buildable = new EditableExecNewPodHook(fluent.getCommand(),fluent.getContainerName(),fluent.getEnv());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
ExecNewPodHookBuilder that = (ExecNewPodHookBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.29-sources.jar: annotations/io/fabric8/openshift/api/model/ExecNewPodHookBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class ExecNewPodHookBuilder extends ExecNewPodHookFluentImpl<ExecNewPodHookBuilder> implements VisitableBuilder<ExecNewPodHook,ExecNewPodHookBuilder>{

     ExecNewPodHookFluent<?> fluent;
public ExecNewPodHookBuilder(){
    this(new ExecNewPodHook());
}
public ExecNewPodHookBuilder( ExecNewPodHookFluent<?> fluent ){
    this(fluent, new ExecNewPodHook());
}
public ExecNewPodHookBuilder( ExecNewPodHookFluent<?> fluent , ExecNewPodHook instance ){
    this.fluent = fluent; fluent.withCommand(instance.getCommand()); fluent.withContainerName(instance.getContainerName()); fluent.withEnv(instance.getEnv()); 
}
public ExecNewPodHookBuilder( ExecNewPodHook instance ){
    this.fluent = this; this.withCommand(instance.getCommand()); this.withContainerName(instance.getContainerName()); this.withEnv(instance.getEnv()); 
}

public EditableExecNewPodHook build(){
    EditableExecNewPodHook buildable = new EditableExecNewPodHook(fluent.getCommand(),fluent.getContainerName(),fluent.getEnv());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
ExecNewPodHookBuilder that = (ExecNewPodHookBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
